@@ -3,6 +3,7 @@
 cache_environ <- new.env(parent = emptyenv())
 cache_environ$use_cache <- NULL
 cache_environ$epidatr_cache <- NULL
+cache_environ$cache_args <- NULL
 
 #' Create or renew a cache for this session
 #' @aliases set_cache
@@ -169,6 +170,12 @@ set_cache <- function(cache_dir = NULL,
       max_age = days * 24 * 60 * 60,
       logfile = file.path(cache_dir, logfile)
     )
+    cache_environ$cache_args <- list(
+      cache_dir = cache_dir,
+      days = days,
+      max_size = max_size,
+      logfile = logfile
+    )
   }
 
   cli::cli_inform(c(
@@ -183,9 +190,9 @@ set_cache <- function(cache_dir = NULL,
 #' Manually reset the cache, deleting all currently saved data and starting afresh
 #' @description
 #' Deletes the current cache and resets a new cache. Deletes local data! If you
-#'   are using a session unique cache, you will have to pass the arguments you
-#'   used for `set_cache` earlier, otherwise the system-wide `.Renviron`-based
-#'   defaults will be used.
+#'   are using a session unique cache, the previous settings will be reused. If
+#'   you pass in new `set_cache` arguments, they will take precedence over the
+#'   previous settings.
 #' @param disable instead of setting a new cache, disable caching entirely;
 #'   defaults to `FALSE`
 #' @inheritDotParams set_cache
@@ -195,14 +202,26 @@ set_cache <- function(cache_dir = NULL,
 #'   [`disable_cache`] to only disable without deleting, and [`cache_info`]
 #' @export
 #' @import cachem
+#' @importFrom rlang dots_list inject
 clear_cache <- function(..., disable = FALSE) {
   if (any(!is.na(cache_environ$epidatr_cache))) {
     cache_environ$epidatr_cache$destroy()
+    recovered_args <- cache_environ$cache_args
+    cache_environ$cache_args <- NULL
+  } else {
+    recovered_args <- list()
   }
+  args <- dots_list(
+    ...,
+    confirm = FALSE,
+    !!!recovered_args,
+    .homonyms = "first",
+    .ignore_empty = "all"
+  )
   if (disable) {
     cache_environ$epidatr_cache <- NULL
   } else {
-    set_cache(...)
+    inject(set_cache(!!!args))
   }
 }
 
@@ -234,68 +253,85 @@ disable_cache <- function() {
 #'   disable without deleting
 #' @export
 cache_info <- function() {
-  if (is.null(cache_environ$epidatr_cache)) {
-    return("there is no cache")
-  } else {
+  if (is_cache_enabled()) {
     return(cache_environ$epidatr_cache$info())
+  } else {
+    return("there is no cache")
   }
 }
 
-#' Dispatch caching
+#' Check if the cache is enabled
+#' @keywords internal
+is_cache_enabled <- function() {
+  !is.null(cache_environ$epidatr_cache)
+}
+
+#' Helper that checks whether a call is actually cachable
+#'
+#' The cacheable endpoints are those with `as_of` or `issues` parameters:
+#' - pub_covidcast
+#' - pub_covid_hosp_state_timeseries
+#' - pub_ecdc_ili
+#' - pub_flusurv
+#' - pub_fluview_clinical
+#' - pub_fluview
+#' - pub_kcdc_ili
+#' - pub_nidss_flu
+#' - pub_paho_dengue
+#'
+#' @keywords internal
+check_is_cachable <- function(epidata_call, fetch_args) {
+  as_of_cachable <- !is.null(epidata_call$params$as_of) && !identical(epidata_call$params$as_of, "*")
+  issues_cachable <- !is.null(epidata_call$params$issues) && !identical(epidata_call$params$issues, "*")
+  is_cachable <- (
+    # Cache should be enabled
+    is_cache_enabled() &&
+      # Call should be cachable
+      (as_of_cachable || issues_cachable) &&
+      # This should not be a dry run
+      !fetch_args$dry_run &&
+      # Base url should be null
+      is.null(fetch_args$base_url) &&
+      # Don't cache debug calls
+      !fetch_args$debug &&
+      # Format type should be json
+      fetch_args$format_type == "json" &&
+      # Fields should be null
+      is.null(fetch_args$fields) &&
+      # Disable date parsing should be false
+      !fetch_args$disable_date_parsing &&
+      # Disable data frame parsing should be false
+      !fetch_args$disable_data_frame_parsing &&
+      # Refresh cache should be false
+      fetch_args$refresh_cache == FALSE
+  )
+  return(is_cachable)
+}
+
+#' Check for warnings for the cache
 #'
 #' @description
-#' The guts of caching, its interposed between fetch and the specific fetch
-#' methods. Internal method only.
+#' Adds warnings when arguments are potentially too recent to use with the cache.
 #'
 #' @param epidata_call the `epidata_call` object
 #' @param fetch_args the args list for fetch as generated by [`fetch_args_list()`]
 #' @keywords internal
-#' @importFrom openssl md5
-cache_epidata_call <- function(epidata_call, fetch_args = fetch_args_list()) {
-  is_cachable <- check_is_cachable(epidata_call, fetch_args)
-  if (is_cachable) {
-    target <- request_url(epidata_call)
-    hashed <- md5(target)
-    cached <- cache_environ$epidatr_cache$get(hashed)
-    as_of_recent <- check_is_recent(epidata_call$params$as_of, 7)
-    issues_recent <- check_is_recent(epidata_call$params$issues, 7)
-    if (as_of_recent || issues_recent) {
-      cli::cli_warn(
-        c(
-          "Using cached results with `as_of` within the past week (or the future!).
+check_for_cache_warnings <- function(epidata_call, fetch_args) {
+  as_of_recent <- check_is_recent(epidata_call$params$as_of, 7)
+  issues_recent <- check_is_recent(epidata_call$params$issues, 7)
+  if (as_of_recent || issues_recent) {
+    cli::cli_warn(
+      c(
+        "Using cached results with `as_of` within the past week (or the future!).
           This will likely result in an invalid cache. Consider",
-          "i" = "disabling the cache for this session with `disable_cache` or
+        "i" = "disabling the cache for this session with `disable_cache` or
           permanently with environmental variable `EPIDATR_USE_CACHE=FALSE`",
-          "i" = "setting `EPIDATR_CACHE_MAX_AGE_DAYS={Sys.getenv('EPIDATR_CACHE_MAX_AGE_DAYS
+        "i" = "setting `EPIDATR_CACHE_MAX_AGE_DAYS={Sys.getenv('EPIDATR_CACHE_MAX_AGE_DAYS
           ', unset = 1)}` to e.g. `3/24` (3 hours)."
-        ),
-        .frequency = "regularly",
-        .frequency_id = "cache timing issues",
-        class = "cache_recent_data"
-      )
-    }
-    if (!is.key_missing(cached)) {
-      cli::cli_warn(
-        c(
-          "Loading from the cache at {cache_environ$epidatr_cache$info()$dir};
-          see {cache_environ$epidatr_cache$info()$logfile} for more details."
-        ),
-        .frequency = "regularly",
-        .frequency_id = "using the cache",
-        class = "cache_access"
-      )
-      return(cached[[1]])
-    }
+      ),
+      .frequency = "regularly",
+      .frequency_id = "cache timing issues",
+      class = "cache_recent_data"
+    )
   }
-  # need to actually get the data, since its either not in the cache or we're not caching
-  runtime <- system.time(if (epidata_call$only_supports_classic) {
-    fetched <- fetch_classic(epidata_call, fetch_args)
-  } else {
-    fetched <- fetch_tbl(epidata_call, fetch_args)
-  })
-  # add it to the cache if appropriate
-  if (is_cachable) {
-    cache_environ$epidatr_cache$set(hashed, list(fetched, Sys.time(), runtime))
-  }
-  return(fetched)
 }
